==> ecuacion-splib-web-1.90.0-sources.jar: jp/ecuacion/splib/web/config/SplibWebSecurityConfig.java <==
package jp.ecuacion.splib.web.config;


import java.util.Arrays;
import java.util.List;
import org.springframework.boot.autoconfigure.security.servlet.PathRequest;
import org.springframework.context.annotation.Bean;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.security.web.SecurityFilterChain;
import org.springframework.security.web.servlet.util.matcher.MvcRequestMatcher;
import org.springframework.web.servlet.handler.HandlerMappingIntrospector;

/**
 * WebSecurityConfigのtemplate。 defaultSuccessUrlだけはシステム個別で設定したくなるため、abstractクラスとする。
 */
public abstract class SplibWebSecurityConfig {

  protected PasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

  /** ログイン成功時の遷移先を指定。 */
  protected abstract String getDefaultSuccessUrl();

  /** 
   * ログインが必要なurlにアクセスした際の遷移先。login画面の場合と、それ以前の説明画面などの場合があるため個別設定可能とした。 
   */
  protected abstract String getUrlWithLoginNeededPageAccessed();

  protected abstract List<AuthorizationBean> getRoleInfo();

  protected abstract List<AuthorizationBean> getAuthorityInfo();
  
  /** 
   * accessDeniedPageは、非ログイン時にpermitAllでないパスにアクセスした場合に加え、csrf tokenのエラーの場合も発生。
   * 後者は、イコールpermitAllのpathにアクセスした場合に毎度発生することになるため、特にログインのないアプリでは設定変更が必要。
   * ただし、abstractにはせず任意での変更項目としておく。
   *  */
  protected String getAccessDeniedPage() {
    return "/public/login/page?accessDenied";
  }

  @Bean
  PasswordEncoder passwordEncoder() {
    return passwordEncoder;
  }

  @Bean
  MvcRequestMatcher.Builder mvc(HandlerMappingIntrospector introspector) {
    return new MvcRequestMatcher.Builder(introspector);
  }

  @Bean
  SecurityFilterChain filterChain(HttpSecurity http, MvcRequestMatcher.Builder mvc)
      throws Exception {
    http.httpBasic(basic -> basic.disable());

    http.formLogin(login -> login.loginPage(getUrlWithLoginNeededPageAccessed())
            .loginProcessingUrl("/public/login/action").usernameParameter("login.username")
            .passwordParameter("login.password").defaultSuccessUrl(getDefaultSuccessUrl(), true)
            .failureUrl("/public/login/page?error"));

    http.authorizeHttpRequests(requests -> requests
            .requestMatchers(PathRequest.toStaticResources().atCommonLocations()).permitAll()
            .requestMatchers(mvc.pattern("/public/**")).permitAll()
            .requestMatchers(mvc.pattern("/ecuacion/public/**")).permitAll());

    if (getRoleInfo() != null) {
      for (AuthorizationBean bean : getRoleInfo()) {
        List<MvcRequestMatcher> list =
            Arrays.asList(bean.requestMatchers).stream().map(str -> mvc.pattern(str)).toList();
        http.authorizeHttpRequests(requests -> requests
                  .requestMatchers(list.toArray(new MvcRequestMatcher[list.size()]))
                  .hasAnyRole(bean.roleOrAuthority));
      }
    }

    if (getAuthorityInfo() != null) {
      for (AuthorizationBean bean : getAuthorityInfo()) {
        http.authorizeHttpRequests(requests -> requests.requestMatchers(bean.requestMatchers)
                  .hasAnyAuthority(bean.roleOrAuthority));
      }
    }

    http.authorizeHttpRequests(requests -> requests.anyRequest().authenticated());

    http.logout(logout -> logout.logoutUrl("/public/logout")
        .logoutSuccessUrl("/public/login/page?logoutDone"));

    http.exceptionHandling(handling -> handling.accessDeniedPage(getAccessDeniedPage()));

    return http.build();
  }

  public static class AuthorizationBean {
    private String[] requestMatchers;
    private String[] roleOrAuthority;

    public AuthorizationBean() {

    }

    public AuthorizationBean(String requestMatchers, String roleOrAuthority) {
      this.requestMatchers = new String[] {requestMatchers};
      this.roleOrAuthority = new String[] {roleOrAuthority};
    }

    public AuthorizationBean(String[] requestMatchers, String roleOrAuthority) {
      this.roleOrAuthority = new String[] {roleOrAuthority};
      this.requestMatchers = requestMatchers;
    }

    public AuthorizationBean(String[] requestMatchers, String[] roleOrAuthority) {
      this.roleOrAuthority = roleOrAuthority;
      this.requestMatchers = requestMatchers;
    }

    public String[] getRequestMatchers() {
      return requestMatchers;
    }

    public void setRequestMatchers(String[] requestMatchers) {
      this.requestMatchers = requestMatchers;
    }

    public String[] getRoleOrAuthority() {
      return roleOrAuthority;
    }

    public void setRoleOrAuthority(String[] roleOrAuthority) {
      this.roleOrAuthority = roleOrAuthority;
    }
  }
}

==> ecuacion-splib-web-1.112.0-sources.jar: jp/ecuacion/splib/web/config/SplibWebSecurityConfig.java <==
package jp.ecuacion.splib.web.config;


import java.util.List;
import org.springframework.boot.autoconfigure.security.servlet.PathRequest;
import org.springframework.context.annotation.Bean;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.security.web.SecurityFilterChain;
import org.springframework.security.web.servlet.util.matcher.MvcRequestMatcher;
import org.springframework.web.servlet.handler.HandlerMappingIntrospector;

/**
 * WebSecurityConfigのtemplate。 defaultSuccessUrlだけはシステム個別で設定したくなるため、abstractクラスとする。
 */
public abstract class SplibWebSecurityConfig {

  protected PasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

  /** ログイン成功時の遷移先を指定。 */
  protected abstract String getDefaultSuccessUrl();

  /**
   * ログインが必要なurlにアクセスした際の遷移先。login画面の場合と、それ以前の説明画面などの場合があるため個別設定可能とした。
   */
  protected abstract String getUrlWithLoginNeededPageAccessed();

  protected abstract List<AuthorizationBean> getRoleInfo();

  protected abstract List<AuthorizationBean> getAuthorityInfo();

  /**
   * accessDeniedPageは、非ログイン時にpermitAllでないパスにアクセスした場合に加え、csrf tokenのエラーの場合も発生。
   * 後者は、イコールpermitAllのpathにアクセスした場合に毎度発生することになるため、特にログインのないアプリでは設定変更が必要。
   * ただし、abstractにはせず任意での変更項目としておく。
   */
  protected String getAccessDeniedPage() {
    return "/public/login/page?accessDenied";
  }

  @Bean
  PasswordEncoder passwordEncoder() {
    return passwordEncoder;
  }

  @Bean
  MvcRequestMatcher.Builder mvc(HandlerMappingIntrospector introspector) {
    return new MvcRequestMatcher.Builder(introspector);
  }

  @Bean
  SecurityFilterChain filterChain(HttpSecurity http, MvcRequestMatcher.Builder mvc)
      throws Exception {

    http.httpBasic(basic -> basic.disable());

    http.formLogin(login -> login.loginPage(getUrlWithLoginNeededPageAccessed())
        .loginProcessingUrl("/public/login/action").usernameParameter("login.username")
        .passwordParameter("login.password").defaultSuccessUrl(getDefaultSuccessUrl(), true)
        .failureUrl("/public/login/page?error"));

    http.authorizeHttpRequests(
        requests -> requests.requestMatchers(PathRequest.toStaticResources().atCommonLocations())
            .permitAll().requestMatchers(mvc.pattern("/public/**")).permitAll()
            .requestMatchers(mvc.pattern("/ecuacion/public/**")).permitAll());

    if (getRoleInfo() != null) {
      for (AuthorizationBean bean : getRoleInfo()) {
        http.authorizeHttpRequests(requests -> requests.requestMatchers(bean.getRequestMatchers())
            .hasAnyRole(bean.getRoleOrAuthorities()));
      }
    }

    if (getAuthorityInfo() != null) {
      for (AuthorizationBean bean : getAuthorityInfo()) {
        http.authorizeHttpRequests(requests -> requests.requestMatchers(bean.getRequestMatchers())
            .hasAnyAuthority(bean.getRoleOrAuthorities()));
      }
    }

    http.authorizeHttpRequests(requests -> requests.anyRequest().authenticated());

    http.logout(logout -> logout.logoutUrl("/public/logout")
        .logoutSuccessUrl("/public/login/page?logoutDone"));

    http.exceptionHandling(handling -> handling.accessDeniedPage(getAccessDeniedPage()));

    return http.build();
  }
}
